import Config from "./types/Config";
import Permission, { ListPermissionOptions } from "./types/Permission";
import Role, { ListRoleOptions } from "./types/Role";
import Tenant, { ListTenantOptions } from "./types/Tenant";
import User, { ListUserOptions } from "./types/User";
import Warrant, { ListWarrantOptions } from "./types/Warrant";
import Session from "./types/Session";
import WarrantCheck from "./types/WarrantCheck";
import PermissionCheck from "./types/PermissionCheck";
export default class Client {
    private readonly config;
    private readonly httpClient;
    constructor(config: Config);
    getTenant(tenantId: string): Promise<Tenant>;
    createTenant(tenant?: Tenant): Promise<Tenant>;
    updateTenant(tenantId: string, tenant: Tenant): Promise<Tenant>;
    deleteTenant(tenantId: string): Promise<void>;
    listTenants(listOptions?: ListTenantOptions): Promise<Tenant[]>;
    listTenantsForUser(userId: string, listOptions?: ListTenantOptions): Promise<Tenant[]>;
    getUser(userId: string): Promise<User>;
    createUser(user?: User): Promise<User>;
    updateUser(userId: string, user: User): Promise<User>;
    deleteUser(userId: string): Promise<void>;
    listUsers(listOptions?: ListUserOptions): Promise<User[]>;
    listUsersForTenant(tenantId: string, listOptions?: ListUserOptions): Promise<User[]>;
    addUserToTenant(tenantId: string, userId: string): Promise<Warrant>;
    removeUserFromTenant(tenantId: string, userId: string): Promise<void>;
    getRole(roleId: string): Promise<Role>;
    createRole(role: Role): Promise<Role>;
    deleteRole(roleId: string): Promise<void>;
    listRoles(listOptions?: ListRoleOptions): Promise<Role[]>;
    listRolesForUser(userId: string, listOptions?: ListRoleOptions): Promise<Role[]>;
    assignRoleToUser(userId: string, roleId: string): Promise<Role>;
    removeRoleFromUser(userId: string, roleId: string): Promise<void>;
    getPermission(permissionId: string): Promise<Permission>;
    createPermission(permission: Permission): Promise<Permission>;
    deletePermission(permissionId: string): Promise<void>;
    listPermissions(listOptions?: ListPermissionOptions): Promise<Permission[]>;
    listPermissionsForUser(userId: string, listOptions?: ListPermissionOptions): Promise<Permission[]>;
    listPermissionsForRole(roleId: string, listOptions?: ListPermissionOptions): Promise<Permission[]>;
    assignPermissionToUser(userId: string, permissionId: string): Promise<Permission>;
    removePermissionFromUser(userId: string, permissionId: string): Promise<void>;
    assignPermissionToRole(roleId: string, permissionId: string): Promise<Permission>;
    removePermissionFromRole(roleId: string, permissionId: string): Promise<void>;
    createWarrant(warrant: Warrant): Promise<Warrant>;
    deleteWarrant(warrant: Warrant): Promise<void>;
    listWarrants(listOptions?: ListWarrantOptions): Promise<Warrant[]>;
    /**
     * Creates an authorization session in Warrant for the specified userId and returns a session token that can be used to
     * make authorization requests to the Warrant API scoped to the specified userId and tenantId.
     *
     * @param session A session object containing the userId, redirectUrl, and optional tenantId for which the authorization session should be created.
     * @returns A session token that can be passed to any of the Warrant client-side SDKs to allow the SDK to make client-side authorization checks for the specified user.
     */
    createAuthorizationSession(session: Session): Promise<string>;
    /**
     * Creates a self-service session in Warrant for the user with the specified userId and returns a session token that can be used to
     * make authorized requests to the Warrant API scoped to the specified userId and tenantId.
     *
     * @param session A session object containing the userId, redirectUrl, and optional tenantId for which the self service session should be created.
     * @returns A url pointing to the self-service dashboard that will allow the specified user to make changes to the roles and permissions of users in their tenant.
     */
    createSelfServiceSession(session: Session, redirectUrl: string): Promise<string>;
    /**
     * Checks against the warrants defined for your application to determine if the given `userId` has the given
     * `relation` to the given `objectId` of type `objectType`. Returns true if the the relation exists and false otherwise.
     * @param objectType The type of the object for which access is being checked.
     * @param objectId The id of the object for which access is being checked.
     * @param relation The relation to the object for which access is being checked.
     * @param userId The userId for which access is being checked.
     * @returns True if the `userId` has the given `relation` to `objectId` of type `objectType`, and false otherwise.
     */
    /**
     * Checks against the warrants defined for your application to determine if the given `userId` has the given
     * `relation` to the given `objectId` of type `objectType`. Returns true if the the relation exists and false otherwise.
     * @param options access check options for this authorization request, including the objectType, objectId, relation, and subject
     * for which access is being checked.
     * @returns True if the `subject` has the given `relation` to `objectId` of type `objectType`, and false otherwise.
     */
    isAuthorized(warrantCheck: WarrantCheck): Promise<boolean>;
    private authorize;
    private edgeAuthorize;
    hasPermission(permissionCheck: PermissionCheck): Promise<boolean>;
}
